bayespy.inference.vmp.nodes.categorical.CategoricalDistribution.plates_from_parent
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical

.. automethod:: CategoricalDistribution.plates_from_parent